@@ -1,9 +1,14 @@
 import os
 
+if os.name == "nt":
+    from quodlibet.plugins import PluginNotSupportedError
+    raise PluginNotSupportedError
+
 from gi.repository import Gtk, GObject
 
 from quodlibet import util
 from quodlibet.plugins.editing import RenameFilesPlugin
+from quodlibet.util.path import iscommand
 
 
 class Kakasi(RenameFilesPlugin, Gtk.CheckButton):
@@ -42,7 +47,7 @@ class Kakasi(RenameFilesPlugin, Gtk.CheckButton):
             return values
 
 
-if not util.iscommand("kakasi"):
+if not iscommand("kakasi"):
     from quodlibet import plugins
     raise plugins.PluginImportException(
         "Couldn't find the 'Kanji Kana Simple Inverter' (kakasi).")
