@@ -1,9 +1,15 @@
-# Copyright 2011 Christoph Reiter <christoph.reiter@gmx.at>
+# Copyright 2011 Christoph Reiter <reiter.christoph@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of version 2 of the GNU General Public License as
 # published by the Free Software Foundation.
 
+import os
+
+if os.name == "nt":
+    from quodlibet.plugins import PluginNotSupportedError
+    raise PluginNotSupportedError
+
 from gi.repository import Gtk
 import dbus
 
@@ -24,8 +30,17 @@ class ScreensaverPause(EventPlugin):
 
     __was_paused = False
     __interface = None
+    __active = False
+    __watch = None
 
     def __screensaver_changed(self, active):
+        # Gnome-Shell fires ActiveChanged even if it doesn't change
+        # (aborted transition to lock screen), so handle that
+
+        if active == self.__active:
+            return
+        self.__active = active
+
         if active:
             self.__was_paused = app.player.paused
             app.player.paused = True
@@ -46,13 +61,18 @@ class ScreensaverPause(EventPlugin):
             iface = dbus.Interface(obj, self.DBUS_INTERFACE)
             self.__sig = iface.connect_to_signal("ActiveChanged",
                                                  self.__screensaver_changed)
+            self.__active = iface.GetActive()
             self.__interface = iface
 
     def enabled(self):
-        bus = dbus.SessionBus()
-        self.__watch = bus.watch_name_owner(self.DBUS_NAME,
-                                            self.__owner_changed)
+        try:
+            bus = dbus.SessionBus()
+            self.__watch = bus.watch_name_owner(self.DBUS_NAME,
+                                                self.__owner_changed)
+        except dbus.DBusException:
+            pass
 
     def disabled(self):
-        self.__watch.cancel()
+        if self.__watch:
+            self.__watch.cancel()
         self.__remove_interface()
